from __future__ import print_function
import getpass
import os
import sys

def main():
    password = getpass.getpass()

    SPACING = ' ' * 3
    print(SPACING.join(password))
    print(SPACING.join([str(i) for i in range(1, len(password) + 1)]))

    CLEAR_MSG = 'Press any key to clear the screen'
    if sys.version_info >= (3, 0):
        input(CLEAR_MSG)
    else:
        raw_input(CLEAR_MSG)

    # http://stackoverflow.com/questions/2084508/clear-terminal-in-python
    os.system('cls' if os.name == 'nt' else 'clear')

if __name__ == '__main__':
    main()



from __future__ import print_function
from setuptools import setup
import io
import os

import passletters

here = os.path.abspath(os.path.dirname(__file__))

def read(*filenames, **kwargs):
    encoding = kwargs.get('encoding', 'utf-8')
    sep = kwargs.get('sep', '\n')
    buf = []
    for filename in filenames:
        with io.open(filename, encoding=encoding) as f:
            buf.append(f.read())
    return sep.join(buf)

long_description = read('README.md')

setup(
    name='passletters',
    version=passletters.__version__,
    url='http://github.com/inversion/passletters',
    license='The MIT License',
    author='Andrew Moss',
    author_email='andrew@mossage.co.uk',
    description='Read password from stdin and echo it with letters enumerated. Clear terminal afterwards.',
    long_description=long_description,
    packages=['passletters'],
    include_package_data=True,
    platforms='any',
    classifiers = [
        'Programming Language :: Python',
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Natural Language :: English',
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Utilities',
        ],
    entry_points = {
        'console_scripts': [
            'passletters = passletters.passletters:main'
        ]
    }
)
